import React, { CSSProperties, ReactElement, Component, ReactNode } from 'react';
import { AxiosInstance } from 'axios';

declare enum PluginLoadType {
    Micro = "Micro",
    Iframe = "Iframe",
    RemoteJs = "RemoteJs",
    Redirect = "Redirect"
}
interface ContextMessage {
    context: {
        [key: string]: any;
    };
    frame: PluginManifest;
}
interface PluginManifest {
    app: {
        id: string;
        name: string;
        key: string;
        env: Record<string, any>[];
    };
    key: string;
    title: string;
    originalKey: string;
    route?: string;
    resource: {
        key: string;
        url: string;
    };
    loadType?: PluginLoadType;
}

interface Props$1 {
    frameURL: string;
    moduleKey: string;
    frameProps: ContextMessage;
    onRefreshContext?: () => void;
    iframeStyle?: CSSProperties;
    iframeClass?: string;
}
declare const CustomIframe: React.FC<Props$1>;

interface RefProps {
    setGlobalState: (data: any) => void;
}
interface StateChangeProps {
    data: any;
}
declare type IQiankunGlobalStateChange = (state: StateChangeProps, prev: StateChangeProps) => void;
interface QiankunComponentProps {
    url: string;
    moduleKey: string;
    qiankunGlobalStateChange?: IQiankunGlobalStateChange;
    qiankunProps?: {
        [key: string]: any;
    };
    pluginKey?: string;
    qiankunStyle?: CSSProperties;
    qiankunClass?: string;
}
declare const QiankunComponent: React.ForwardRefExoticComponent<QiankunComponentProps & React.RefAttributes<RefProps>>;

interface RemoteComponentProps {
    url: string;
    moduleKey?: string;
    pluginKey?: string;
    contextProps?: {
        [key: string]: any;
    };
}
declare const RemoteComponent: React.FC<RemoteComponentProps>;

interface IPluginErrorContainerProps {
    reason: any;
    style: CSSProperties;
    onRetry: () => void;
}
interface IUsePluginGlobalConfig {
    remoteComponentGetDependencies?: (moduleName?: string) => any;
    pluginErrorBoundary?: React.FC<IPluginErrorContainerProps>;
    remoteComponentErrorBoundary?: RemoteComponentErrorBoundaryType;
    globalInitProps: Record<string, any>;
    axiosInstance: AxiosInstance;
    pluginLoadingWrapper?: (loadingStatus: boolean, moduleKey: string, children: React.ReactNode) => ReactElement;
}
declare const PluginGlobalConfigContext: React.Context<IUsePluginGlobalConfig>;

declare const usePluginGlobalConfig: () => IUsePluginGlobalConfig;

declare type Props = {
    children: ReactNode;
    errorText?: string;
};
declare type MyState = {
    hasError: boolean;
};
declare type RemoteComponentErrorBoundaryType = typeof RemoteComponentErrorBoundary;
declare class RemoteComponentErrorBoundary extends Component<Props, MyState> {
    constructor(props: Props);
    static getDerivedStateFromError(): MyState;
    render(): ReactNode;
}
declare const loadRemoteComponentFactory: (getModule: any) => (name: any, contextProps: any) => any;
declare const loadRemoteComponent: any;

export { CustomIframe, IQiankunGlobalStateChange, IUsePluginGlobalConfig, PluginGlobalConfigContext, QiankunComponent, RemoteComponent, RemoteComponentErrorBoundary, RemoteComponentErrorBoundaryType, StateChangeProps, loadRemoteComponent, loadRemoteComponentFactory, usePluginGlobalConfig };
